"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _screenfull = _interopRequireDefault(require("screenfull"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-env browser */

/**
 * The underlying scrollContainerRef should be an actual node, not a Fragment. Otherwise, it will just be null
 * You HAVE to make sure overflow-x is not set on the scrollContainerRef or body. This will make scrollTop default to 0 on Chrome Mobile
 */
var getFullScreenNode = function getFullScreenNode() {
  return document.documentElement || document.body;
};

var isMobile = function isMobile(maxPixelsForMobile) {
  if (typeof window === "undefined") {
    return false;
  }

  var width = window.innerWidth;
  return width <= maxPixelsForMobile;
};

var Screenfull = function Screenfull(_ref) {
  var scrollContainerRef = _ref.scrollContainerRef,
      forceFullScreen = _ref.forceFullScreen,
      mobileOnly = _ref.mobileOnly,
      maxPixelsForMobile = _ref.maxPixelsForMobile;

  var scroll = _react["default"].useRef(0);

  var handleScroll = _react["default"].useCallback(function (event) {
    var scrollPos = event.currentTarget.scrollTop;
    var going = "down";
    var scrollCurrent = scroll.current;

    if (scrollCurrent !== 0 && scrollPos < scrollCurrent) {
      going = "up";
    }

    scroll.current = scrollPos;

    if (going === "up" && _screenfull["default"].isFullscreen) {
      _screenfull["default"].exit();
    } else if (going === "down" && !_screenfull["default"].isFullscreen) {
      _screenfull["default"].request(getFullScreenNode());
    }
  }, []);

  var getNode = _react["default"].useCallback(function () {
    return scrollContainerRef ? _reactDom["default"].findDOMNode(scrollContainerRef) // eslint-disable-line react/no-find-dom-node
    : typeof document !== "undefined" && document.body;
  });

  _react["default"].useEffect(function () {
    if (mobileOnly && !isMobile(maxPixelsForMobile)) {
      return;
    }

    if (forceFullScreen) {
      if (_screenfull["default"].isEnabled) {
        _screenfull["default"].request(getFullScreenNode());
      }

      return;
    }

    var node = getNode();

    if (node && _screenfull["default"].isEnabled) {
      node.addEventListener("scroll", handleScroll, {
        passive: true
      }, true);
    }
  }, [mobileOnly, forceFullScreen]);

  _react["default"].useEffect(function () {
    return function () {
      if (_screenfull["default"].isEnabled) {
        _screenfull["default"].exit();
      }

      var node = getNode();

      if (node) {
        node.removeEventListener("scroll", handleScroll);
      }
    };
  }, []);

  return null;
};

Screenfull.defaultProps
/* remove-proptypes */
= {
  scrollContainerRef: null,
  forceFullScreen: false,
  mobileOnly: true,
  maxPixelsForMobile: 768
};
var _default = Screenfull;
exports["default"] = _default;